#! /bin/sh
#
#------------------------------------------------------------------------------
# /tmp/install.sh :	setting up APCUPSD Power Management on EISFAIR
#
# last edited:             31.08.2004
#
# Copyright (c) 2004       Gunther Schmidt
#	                   1012-621@online.de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#------------------------------------------------------------------------------

HPATH='/etc/init.d/halt'	
RETURN='pass'
KERNEL=$(uname -r)
MOD_PATH='/lib/modules/'${KERNEL}'/kernel/drivers/usb'

CHECK_STATE ()
{
if [ $RETURN ]; then
	colecho "done!" gn
else
	RETURN='pass'
	colecho "failed!" br x brbl
fi
}

CREATE_HID_DIR ()
{
    echo -n "...creating directory /dev/usb/hid... "
    mkdir -p /dev/usb/hid || RETURN=''
    CHECK_STATE
}

CREATE_HID_NODES ()
{
    echo "...creating device nodes..."
    m=0
    n=96

    while [ ${m} -le 15 ]; do
        echo -n "...hiddev${m}... "
        mknod /dev/usb/hid/hiddev${m} c 180 ${n} 2>/dev/null || RETURN=''
        CHECK_STATE
        let m+=1
        let n+=1
    done
}


echo -n "...creating links... "
ln -sf /etc/init.d/apcupsd /etc/rc2.d/S70apcupsd || RETURN=''
ln -sf /etc/init.d/apcupsd /etc/rc2.d/K39apcupsd || RETURN=''
ln -sf /etc/init.d/apcupsd /sbin/apcups || RETURN=''
CHECK_STATE

if [ -f ${HPATH}.BackUp ]; then
	colecho "A BackUp-file for the halt-script is already existing," gn
	echo "...skiping modificatiion..."
else
	echo -n "...creating BackUp of halt-script... "
	cp ${HPATH} ${HPATH}.BackUp || RETURN=''
	CHECK_STATE

	echo -n "...modifying halt-script... "
	cp /etc/apcupsd/halt.modified ${HPATH} || RETURN=''
	CHECK_STATE
fi


if [ -f ${MOD_PATH}/hid.o ];then
    echo "...module hid.o exists..."
else
    case $KERNEL in
        "2.4.26-1" | "2.4.26-1-SMP")
                    echo -n "...copying module hid.o to ${MOD_PATH}... "
                    cp /etc/apcupsd/hid-${KERNEL}.o ${MOD_PATH}/hid.o || RETURN=''
                    touch /etc/apcupsd/hid.o_copied
                    CHECK_STATE
    
                    echo "...setting dependencies... "
                    depmod -a 2>/dev/null
                    #CHECK_STATE
                    
                    if [ -d /dev/usb/hid ]; then
                        echo "...found /dev/usb/hid - skipping creation..."
                        test -e /dev/usb/hid/hiddev0 || CREATE_HID_NODES
                    else
                        CREATE_HID_DIR
                        CREATE_HID_NODES
                        touch /etc/apcupsd/hid_dir_created
                    fi
                    ;;
        "*")
                    echo
                    colecho "Invalid Kernel <$KERNEL> there will be no USB support!" br x br
                    colecho "The serial mode will not be affected." br x br
                    echo
                    sleep 10
                    ;;
    esac
fi

echo -n "...creating menu entries... "
/var/install/bin/add-menu   /var/install/menu/setup.services.menu   \
			   /var/install/bin/setup.services.apcups   \
			   "APC UPS power management" || RETURN=''
CHECK_STATE

APACHE=''
test ! -f /var/install/packages/apache || APACHE='apache'
test ! -f /var/install/packages/apache2 || APACHE='apache2'
if [ -n "$APACHE" ]; then
        echo;colecho "Found package >$APACHE<..." gn
        echo -n "   ...installing CGI-files to /var/www/cgi-bin..."
        mv /tmp/apcups/*.cgi /var/www/cgi-bin/ || RETURN=''
        CHECK_STATE
        echo -n "   ...installing CSS-file to /etc/apcupsd..."
        cp /tmp/apcups/*.css /etc/apcupsd/ || RETURN=''
        CHECK_STATE
        
        if [ -f /etc/apcupsd/hosts.bak ]; then
             echo -n "...restoring backup-files..."
             cp -f /etc/apcupsd/hosts.bak /etc/apcupsd/hosts.conf || RETURN=''
             cp -f /etc/apcupsd/multimon.bak /etc/apcupsd/multimon.conf || RETURN=''
             CHECK_STATE
        fi

        echo -n "   ...setting access rights for the CGI-package... "
        chown wwwrun:nogroup /var/www/cgi-bin/multimon.cgi || RETURN=''
        chown wwwrun:nogroup /var/www/cgi-bin/upsfstats.cgi || RETURN=''
        chown wwwrun:nogroup /var/www/cgi-bin/upsimage.cgi || RETURN=''
        chown wwwrun:nogroup /var/www/cgi-bin/upsstats.cgi || RETURN=''

        chmod 755 /var/www/cgi-bin/multimon.cgi || RETURN=''
        chmod 755 /var/www/cgi-bin/upsfstats.cgi || RETURN=''
        chmod 755 /var/www/cgi-bin/upsimage.cgi || RETURN=''
        chmod 755 /var/www/cgi-bin/upsstats.cgi || RETURN=''
        CHECK_STATE
else
        colecho "Apache not found, skipping installation of CGI-files..." gn
fi

echo;echo -n "...setting access rights for the main-package... "
chmod 755 /etc/apcupsd || RETURN=''
chmod 755 /etc/apcupsd/* || RETURN=''
chmod 700 /etc/apcupsd/*hid* || RETURN=''
if [ -e /etc/apcupsd/apcupsd.css ]; then
        chmod 644 /etc/apcupsd/apcupsd.css || RETURN=''
fi
chmod 600 /etc/config.d/apcups || RETURN=''
chmod 755 /sbin/apc* || RETURN=''
chmod 755 /usr/share/doc/apcups || RETURN=''
chmod 644 /usr/share/doc/apcups/* || RETURN=''
chmod 755 /var/install/bin/*apcups* || RETURN=''
chmod 700 /var/install/config.d/apcups.sh || RETURN=''
chmod 700 /var/install/deinstall/apcups || RETURN=''
chmod 644 /var/install/menu/*apcups* || RETURN=''
chmod 644 /var/install/packages/apcups || RETURN=''
CHECK_STATE

echo -n "...removing /tmp/preinstall.sh... "
rm -f /tmp/preinstall.sh || RETURN=''
CHECK_STATE

echo -n "...removing /tmp/install.sh... "
rm -f /tmp/install.sh || RETURN=''
CHECK_STATE

echo -n "...removing /tmp/apcups... "
rm -fr /tmp/apcups || RETURN=''
CHECK_STATE

echo
/var/install/bin/anykey
/var/install/bin/apcups-edit
