#!/bin/bash
#------------------------------------------------------------------------------
# /var/install/config.d/apcupsd.sh	- configuration generator script for 
#					  APC UPS Power Management on EISFAIR
# 
# last edited:             21.04.2005
#
# Copyright (c) 2005       Gunther Schmidt
#	                   1012-621@online.de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#------------------------------------------------------------------------------

. /etc/config.d/apcups

CONFFILE='/etc/apcupsd/apcupsd.conf'
OUTFILE='/tmp/apcups.tmp'
RETURN='pass'

CHECK_STATE ()
{
if [ $RETURN ]; then
	colecho "done!" gn
else
	RETURN='pass'
	colecho "failed!" br x brbl
fi
}

clrhome

colecho "Generating /etc/config.d/apcupsd.conf..." gn
echo -n "...checking for old temp.-file... "
if [ -e ${OUTFILE} ]; then
	rm -f $OUTFILE || RETURN=''
fi
CHECK_STATE

echo -n "...writing header to temp.-file... "
(echo "## apcupsd.conf v1.1 ##"
 echo "#------------------------------------------------------------------------------" 
 echo "# Configuration file for APCUPS generated by /var/install/config.d/apcups.sh"
 echo "#"
 echo "# Do not edit this file, edit APC UPS Power Management configuration"
 echo "#------------------------------------------------------------------------------"
 echo " "
 echo " "
) > $OUTFILE || RETURN=''
CHECK_STATE

echo -n "...writing general parameters... "
(echo "#------------------------------------------------------------------------------"
 echo "# General parameters"
 echo "#------------------------------------------------------------------------------"
 echo " "
) >> $OUTFILE
case $UPSCABLE in
	"simple" | "smart" | "940-0020B" | "940-0023A" | "940-0024B" | "940-0024C" |\
	"940-0024C" | "940-0024G" | "940-0095A" | "940-0095B" | "940-0095C" | "ether" | "usb")
		echo "UPSCABLE $UPSCABLE" >> $OUTFILE
	;;
	*)
	if [ ${UPSCABLE} ]; then
		echo ">>> Invalid parameter in UPSCABLE <<<"
	fi
	;;
esac 
case $UPSTYPE in
	"backups" | "sharebasic" | "netups" | "backupspro" | "smartvsups" | "usb" |\
        "newbackupspro" |"backupspropnp" | "smartups" | "matrixups" | "sharesmart")
		echo "UPSTYPE $UPSTYPE" >> $OUTFILE		
	;;
	*)
	if [ ${UPSTYPE} ]; then
		echo ">>> Invalid parameter in UPSTYPE <<<"
	fi
	;;
esac 
case $DEVICE in
	"/dev/ttyS0" | "/dev/ttyS1")
		echo "DEVICE $DEVICE" >> $OUTFILE		
	;;
	"usb" | "USB")
		echo "DEVICE" >> $OUTFILE
	;;
	*)
	if [ ${DEVICE} ]; then
		echo ">>> Invalid parameter in DEVICE <<<"
	fi
	;;
esac 
if [ ${LOCKFILE} ]; then
 echo "LOCKFILE $LOCKFILE" >> $OUTFILE
fi
(echo " "
 echo " "
) >> $OUTFILE
CHECK_STATE

echo -n "...writing parameters used during power failure... "
(echo "#------------------------------------------------------------------------------"
 echo "# Parameters used during power failure"
 echo "#------------------------------------------------------------------------------"
 echo " "
) >> $OUTFILE
if [ ${BATTERYLEVEL} ]; then
	echo "BATTERYLEVEL $BATTERYLEVEL" >> $OUTFILE
fi
if [ ${MINUTES} ]; then
	echo "MINUTES $MINUTES" >> $OUTFILE
fi
if [ ${TIMEOUT} ]; then
	echo "TIMEOUT $TIMEOUT" >> $OUTFILE
fi
if [ ${ANNOY} ]; then
	echo "ANNOY $ANNOY" >> $OUTFILE
fi
if [ ${ANNOYDELAY} ]; then
	echo "ANNOYDELAY $ANNOYDELAY" >> $OUTFILE
fi
case $NOLOGON in
	"disable" | "timeout" | "percent" | "minutes" | "always")
		echo "NOLOGON $NOLOGON" >> $OUTFILE		
	;;
	*)
	if [ ${NOLOGON} ]; then
		echo ">>> Invalid parameter in NOLOGON <<<"
	fi
	;;
esac 
if [ ${KILLDELAY} ]; then
	echo "KILLDELAY $KILLDELAY" >> $OUTFILE
fi
(echo " "
 echo " "
) >> $OUTFILE
CHECK_STATE

echo -n "...writing parameters used by the network information server... "
(echo "#------------------------------------------------------------------------------"
 echo "# Parameters used by the network information server"
 echo "#------------------------------------------------------------------------------"
 echo " "
) >> $OUTFILE
case $NETSERVER in
	"on" | "off")
		echo "NETSERVER $NETSERVER" >> $OUTFILE		
	;;
	*)
	if [ ${NETSERVER} ]; then
		echo ">>> Invalid parameter in NETSERVER <<<"
	fi
	;;
esac 
if [ ${NISPORT} ]; then
	echo "NISPORT $NISPORT" >> $OUTFILE
fi
(echo " "
 echo " "
) >> $OUTFILE
CHECK_STATE

echo -n "...removing old apcupsd NIS entry from /etc/services... "
grep -v "NIS-port for apcups-daemon" /etc/services > /tmp/services.tmp || RETURN=''
cp /tmp/services.tmp /etc/services || RETURN=''
rm -f /tmp/services.tmp || RETURN=''
CHECK_STATE

echo -n "...writing new entry for apcups NIS to /etc/services... "
echo "apcupsd        $NISPORT/tcp         # NIS-port for apcups-daemon" >> /etc/services  || RETURN=''
CHECK_STATE

echo -n "...riting parameters used for system logging... "
(echo "#------------------------------------------------------------------------------"
 echo "# Parameters used for system logging"
 echo "#------------------------------------------------------------------------------"
 echo " "
) >> $OUTFILE
if [ ${EVENTSFILE} ]; then
	echo "EVENTSFILE $EVENTSFILE" >> $OUTFILE
fi
if [ ${STATTIME} ]; then
	echo "STATTIME $STATTIME" >> $OUTFILE
fi
if [ ${STATFILE} ]; then
	echo "STATFILE $STATFILE" >> $OUTFILE
fi
case $LOGSTATS in
	"on" | "off")
		echo "LOGSTATS $LOGSTATS" >> $OUTFILE		
	;;
	*)
	if [ ${LOGSTATS} ]; then
		echo ">>> Invalid parameter in LOGSTATS <<<"
	fi
	;;
esac 
if [ ${DATATIME} ]; then
	echo "DATATIME $DATATIME" >> $OUTFILE
fi
if [ ${FACILITY} ]; then
	echo "FACILITY $FACILITY" >> $OUTFILE
fi
(echo " "
 echo " "
) >> $OUTFILE
CHECK_STATE

echo -n "...writing parameters used while updating the UPS EPROM... "
(echo "#------------------------------------------------------------------------------"
 echo "# Parameters used while updating the UPS EPROM"
 echo "#------------------------------------------------------------------------------"
 echo " "
) >> $OUTFILE
if [ ${UPSNAME} ]; then
	echo "UPSNAME $UPSNAME" >> $OUTFILE
fi
case $BATTDATE in
	??"/"??"/"??)
		echo "BATTDATE $BATTDATE" >> $OUTFILE		
	;;
	*)
	if [ ${BATTDATE} ]; then
		echo ">>> Invalid parameter in BATTDATE <<<"
	fi
	;;
esac
case $SENSITIVITY in
	"H" | "M" | "L")
		echo "SENSITIVITY $SENSITIVITY" >> $OUTFILE		
	;;
	*)
	if [ ${SENSITIVITY} ]; then
		echo ">>> Invalid parameter in SENSITIVITY <<<"
	fi
	;;
esac 
case $WAKEUP in
	"000" | "060" | "180" | "300")
		echo "WAKEUP $WAKEUP" >> $OUTFILE		
	;;
	*)
	if [ ${WAKEUP} ]; then
		echo ">>> Invalid parameter in WAKEUP <<<"
	fi
	;;
esac 
case $SLEEP in
	"020" | "180" | "300" | "600")
		echo "SLEEP $SLEEP" >> $OUTFILE		
	;;
	*)
	if [ ${SLEEP} ]; then
		echo ">>> Invalid parameter in SLEEP <<<"
	fi
	;;
esac 
case $LOTRANSFER in
	"0" | "106" | "103" | "100" | "097" | "177" | "172" | "168" | "162" |\
	"092" | "090" | "088" | "086" | "208" | "204" | "200" | "196")
		echo "LOTRANSFER $LOTRANSFER" >> $OUTFILE		
	;;
	*)
	if [ ${LOTRANSFER} ]; then
		echo ">>> Invalid parameter in LOTRANSFER <<<"
	fi
	;;
esac 
case $HITRANSFER in
	"0" | "127" | "130" | "133" | "136" | "229" | "234" | "239" | "244" |\
	"108" | "110" | "112" | "114" | "253" | "257" | "261" | "265")
		echo "HITRANSFER $HITRANSFER" >> $OUTFILE		
	;;
	*)
	if [ ${HITRANSFER} ]; then
		echo ">>> Invalid parameter in HITRANSFER <<<"
	fi
	;;
esac 
case $RETURNCHARGE in
	"00" | "15" | "50" | "90")
		echo "RETURNCHARGE $RETURNCHARGE" >> $OUTFILE		
	;;
	*)
	if [ ${RETURNCHARGE} ]; then
		echo ">>> Invalid parameter in RETURNCHARGE <<<"
	fi
	;;
esac 
case $BEEPSTATE in
	"0" | "T" | "L" | "N")
		echo "BEEPSTATE $BEEPSTATE" >> $OUTFILE		
	;;
	*)
	if [ ${BEEPSTATE} ]; then
		echo ">>> Invalid parameter in BEEPSTATE <<<"
	fi
	;;
esac 
case $LOWBATT in
	"02" | "05" | "07" | "10")
		echo "LOWBATT $LOWBATT" >> $OUTFILE		
	;;
	*)
	if [ ${LOWBATT} ]; then
		echo ">>> Invalid parameter in LOWBATT <<<"
	fi
	;;
esac 
case $OUTPUTVOLTS in
	"115" | "208" | "100" | "230" | "240" | "220" | "225")
		echo "OUTPUTVOLTS $OUTPUTVOLTS" >> $OUTFILE		
	;;
	*)
	if [ ${OUTPUTVOLTS} ]; then
		echo ">>> Invalid parameter in OUTPUTVOLTS <<<"
	fi
	;;
esac 
case $SELFTEST in
	"336" | "168" | "on" | "off")
		echo "SELFTEST $SELFTEST" >> $OUTFILE		
	;;
	*)
	if [ ${SELFTEST} ]; then
		echo ">>> Invalid parameter in SELFTEST <<<"
	fi
	;;
esac 
(echo " "
 echo " "
) >> $OUTFILE
CHECK_STATE

echo -n "...writing parameters used in network sharing / controlling the UPS... "
(echo "#------------------------------------------------------------------------------"
 echo "# Parameters used for network sharing / controlling the UPS"
 echo "#------------------------------------------------------------------------------"
 echo " "
) >> $OUTFILE
case $UPSCLASS in
	"standalone" | "shareslave" | "sharemaster" | "netslave" | "netmaster")
		echo "UPSCLASS $UPSCLASS" >> $OUTFILE		
	;;
	*)
	if [ ${UPSCLASS} ]; then
		echo ">>> Invalid parameter in UPSCLASS <<<"
	fi
	;;
esac 
case $UPSMODE in
	"disable" | "share" | "net" | "sharenet")
		echo "UPSMODE $UPSMODE" >> $OUTFILE		
	;;
	*)
	if [ ${UPSMODE} ]; then
		echo ">>> Invalid parameter in UPSMODE <<<"
	fi
	;;
esac 
case $NETACCESS in
	"true" | "false")
		echo "NETACCESS $NETACCESS" >> $OUTFILE		
	;;
	*)
	if [ ${NETACCESS} ]; then
		echo ">>> Invalid parameter in UPSMODE <<<"
	fi
	;;
esac 
if [ ${NETTIME} ]; then
	echo "NETTIME $NETTIME" >> $OUTFILE
fi
if [ ${NETPORT} ]; then
	echo "NETPORT $NETPORT" >> $OUTFILE
fi
if [ ${MASTER} ]; then
	echo "MASTER $MASTER" >> $OUTFILE
fi
while [ ${n:=0} != ${SLAVE_N:=0} ]; do
	let n+=1
	eval WORD='$SLAVE_'$n
	if [ ${WORD} ]; then
		echo "SLAVE $WORD" >> $OUTFILE
	fi
done
if [ ${USERMAGIC} ]; then
	echo "USERMAGIC $USERMAGIC" >> $OUTFILE
fi
(echo " "
 echo " "
) >> $OUTFILE
CHECK_STATE

if [ ${NETPORT} ]; then
	echo -n "...removing old apcupsd NET entry from /etc/services... "
        grep -v "NET-port for apcups-daemon" /etc/services > /tmp/services.tmp || RETURN=''
        cp /tmp/services.tmp /etc/services || RETURN=''
        rm -f /tmp/services.tmp || RETURN=''
        CHECK_STATE

        echo -n "...writing new entry for apcups NET to /etc/services... "
        echo "apcupsd        $NETPORT/tcp         # NET-port for apcups-daemon" >> /etc/services  || RETURN=''
        CHECK_STATE
fi

if [ -e ${CONFFILE} ]; then
	echo -n "...writing BACKUP of config-file... "
	cp -f ${CONFFILE} ${CONFFILE}.backup || RETURN=''
	CHECK_STATE
fi

echo -n "...writing config-file... "
cp -f ${OUTFILE} ${CONFFILE} || RETURN=''
CHECK_STATE

echo
colecho "Generating /etc/apcupsd/hosts.conf..." gn
if [ -e /etc/apcupsd/hosts.conf ]; then
	echo -n "...writing BACKUP of config-file... "
	cp -f /etc/apcupsd/hosts.conf /etc/apcupsd/hosts.conf.backup || RETURN=''
	rm -f /etc/apcupsd/hosts.conf
	CHECK_STATE
fi
(echo "#------------------------------------------------------------------------------"
 echo "# Network UPS Tools - hosts.conf"
 echo "#"
 echo "# Do not edit this file! Edit /etc/config.d/apcupsd."
 echo "#"
 echo "#------------------------------------------------------------------------------"
) > /etc/apcupsd/hosts.conf

echo -n "...writing MONITOR-arguments... "
n=1
while [ $n -le $MONITOR_N ]; do
	eval IP='$MONITOR_'$n'_IP'
	eval DESCRIPTION='$MONITOR_'$n'_DESCRIPTION'
	echo "MONITOR "$IP" "\"$DESCRIPTION\" >> /etc/apcupsd/hosts.conf || RETURN=''
        let n+=1
done
CHECK_STATE

echo -n "...setting access-rights..."
chmod 644 /etc/apcupsd/hosts.conf || RETURN=''
CHECK_STATE

echo
colecho "Generating /etc/apcupsd/multimon.conf..." gn
if [ -e /etc/apcupsd/multimon.conf ]; then
	echo -n "...writing BACKUP of config-file... "
	cp -f /etc/apcupsd/multimon.conf /etc/apcupsd/multimon.conf.backup || RETURN=''
	rm -f /etc/apcupsd/multimon.conf
	CHECK_STATE
fi
(echo "#------------------------------------------------------------------------------"
 echo "# Network UPS Tools - multimon.conf"
 echo "#"
 echo "# Do not edit this file! Edit /etc/config.d/apcupsd."
 echo "#"
 echo "#------------------------------------------------------------------------------"
 echo " "
) > /etc/apcupsd/multimon.conf

case $TEMP_MM in
	"Celsius")
		echo "TEMPC" >> /etc/apcupsd/multimon.conf
	;;
	"")
		echo "TEMPF" >> /etc/apcupsd/multimon.conf
	;;
	*)
	if [ ${TEMP_MM} ]; then
		echo ">>> Invalid parameter in TEMP_MM <<<"
	fi
	;;
esac

echo -n "...writing FIELD-arguments... "
echo "" >> /etc/apcupsd/multimon.conf
n=1
while [ $n -le $FIELD_N ]; do
	eval VARIABLE='$FIELD_'$n'_VARIABLE'
	eval NAME='$FIELD_'$n'_NAME'
	eval SUFFIX='$FIELD_'$n'_SUFFIX'
	
	echo "FIELD "$VARIABLE" "\"$NAME\" \"$SUFFIX\" >> /etc/apcupsd/multimon.conf || RETURN=''
        let n+=1
done
CHECK_STATE

echo -n "...setting access-rights... "
chmod 644 /etc/apcupsd/multimon.conf || RETURN=''
CHECK_STATE

echo
colecho "Generating /etc/apcupsd/mailevents.conf..." gn
echo -n "...writing mail-event arguments..."
test ! -f /etc/apcupsd/mailevents.conf || rm /etc/apcupsd/mailevents.conf

for WORD in CHANGEME COMMFAILURE COMMOK MAINSBACK MASTERCONNECT MASTERTIMEOUT ONBATTERY; do
    eval PARAMETER='$'${WORD}
    case $PARAMETER in
        "yes" | "no")
        echo "${WORD}='${PARAMETER}'" >> /etc/apcupsd/mailevents.conf || RETURN=''
        ;;
    	*)
	if [ ${PARAMETER} ]; then
		echo ">>> Invalid parameter in $WORD <<<"
	fi
	;;
    esac
done

( echo "CHANGEME_MSG='"$CHANGEME_MSG"'"
  echo "COMMFAILURE_MSG='"$COMMFAILURE_MSG"'"
  echo "COMMOK_MSG='"$COMMOK_MSG"'"
  echo "MAINSBACK_MSG='"$MAINSBACK_MSG"'"
  echo "MASTERCONNECT_MSG='"$MASTERCONNECT_MSG"'"
  echo "MASTERTIMEOUT_MSG='"$MASTERTIMEOUT_MSG"'"
  echo "ONBATTERY_MSG='"$ONBATTERY_MSG"'"
 ) >> /etc/apcupsd/mailevents.conf || RETURN=''

CHECK_STATE

echo -n "...setting access-rights... "
chmod 644 /etc/apcupsd/mailevents.conf || RETURN=''
CHECK_STATE

echo
echo -n "...removing temp.-file... "
rm -f ${OUTFILE} || RETURN=''
CHECK_STATE
	
echo -n "...writing logrotate-file... "
if [ -e /etc/logrotate.d/apcups ]; then
	rm -f /etc/logrotate.d/apcups
fi
(echo "$EVENTSFILE {"
 echo "		rotate 5"
 echo "		monthly"
 echo "		compress"
 echo "		notifempty"
 echo "		}"
) > /etc/logrotate.d/apcups || RETURN=''
chmod 600 /etc/logrotate.d/apcups
CHECK_STATE

echo;colecho "Restarting..." gn
echo
/sbin/apcups restart
